import click
import os
from pprint import pprint
from click_configfile import ConfigFileReader, Param, SectionSchema
from click_configfile import matches_section


class ConfigSectionSchema(object):
    """Describes all config sections of this configuration file."""

    @matches_section("profile")
    class Profile(SectionSchema):
        name = Param(type=str)
        email = Param(type=str)
        git_provider = Param(type=str)
        config_repo = Param(type=str)


class ConfigFileProcessor(ConfigFileReader):
    home = os.getenv("HOME")
    config_files = [f"{home}/.lfntrc"]
    config_section_schemas = [
        ConfigSectionSchema.Profile,
    ]


CONTEXT_SETTINGS = dict(default_map=ConfigFileProcessor.read_config())


@click.group(context_settings=CONTEXT_SETTINGS)
def lfnt():
    """A python package for eating elephants."""
    pass


lfnt_group = lfnt.group(context_settings=CONTEXT_SETTINGS)
lfnt_command = lfnt.command(context_settings=CONTEXT_SETTINGS)


# init
@lfnt_command
def init():
    """Initialize a .lfntrc file."""
    pass


# install
@lfnt_command
def install():
    """Install a package or application and add to .lfntrc file."""
    pass


@lfnt_command
def uninstall():
    """Uninstall a package or application and remove from .lfntrc file."""
    pass


# sync
@lfnt_command
def sync():
    """Sync local workstation with .lfntrc file."""
    pass


# config
@lfnt_group
def config():
    """Lfnt configuration commands."""
    pass


config_command = config.command(context_settings=CONTEXT_SETTINGS)


@config_command
def show():
    pprint(CONTEXT_SETTINGS["default_map"])


if __name__ == "__main__":
    lfnt()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lfnt']

package_data = \
{'': ['*']}

install_requires = \
['Flask>=2.0.3,<3.0.0',
 'GitPython>=3.1.27,<4.0.0',
 'ansible>=5.5.0,<6.0.0',
 'awscli>=1.22.82,<2.0.0',
 'click-configfile>=0.2.3,<0.3.0',
 'click>=8.0.4,<9.0.0',
 'pulumi>=3.27.0,<4.0.0']

entry_points = \
{'console_scripts': ['lfnt = lfnt.cli:lfnt']}

setup_kwargs = {
    'name': 'lfnt',
    'version': '0.1.0',
    'description': 'A python app for eating elephants.',
    'long_description': None,
    'author': 'Dan Swartz',
    'author_email': '2fifty6@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
